@@ -65,6 +65,7 @@ pub struct RelativityConfig<B: AsRef<Path>> {
     base: Option<B>,
     with_prefix_dots: Option<bool>,
     without_suffix_dots: Option<bool>,
+    without_tilde: Option<bool>,
 }
 
 impl<B: AsRef<Path>> RelativityConfig<B> {
@@ -82,6 +83,11 @@ impl<B: AsRef<Path>> RelativityConfig<B> {
         self.without_suffix_dots = Some(true);
         self
     }
+
+    pub fn without_tilde(mut self) -> Self {
+        self.without_tilde = Some(true);
+        self
+    }
 }
 
 pub fn relative_to<P, B>(
@@ -153,6 +159,14 @@ where
 
     let relative = relative.to_string_lossy().to_string();
 
+    if config.and_then(|c| c.without_tilde).unwrap_or(false) {
+        return if relative.len() < pathstring.len() {
+            Ok(relative)
+        } else {
+            Ok(pathstring)
+        };
+    }
+
     let fromhome = HOME
         .as_ref()
         .and_then(|h| {
